@@ -10,7 +10,7 @@
 occ <- function(query = NULL, from = "gbif", limit = 500, start = NULL,
   page = NULL, geometry = NULL, has_coords = NULL, ids = NULL, date = NULL,
   callopts=list(),
-  gbifopts = list(), bisonopts = list(), inatopts = list(),
+  gbifopts = list(), inatopts = list(),
   ebirdopts = list(), vertnetopts = list(), idigbioopts = list(),
   obisopts = list(), alaopts = list(), throw_warnings = TRUE) {
 
@@ -29,12 +29,12 @@ occ <- function(query = NULL, from = "gbif", limit = 500, start = NULL,
   type <- "sci"
 
   geometry <- occ_geom(geometry)
-  sources <- match.arg(from, choices = c("gbif", "bison", "inat", "ebird",
+  sources <- match.arg(from, choices = c("gbif", "inat", "ebird",
     "vertnet", "idigbio", "obis", "ala"),
     several.ok = TRUE)
 
   # collect all data sources opts into named list to index to later
-  ds <- list(gbif=gbifopts, bison=bisonopts, inat=inatopts,
+  ds <- list(gbif=gbifopts, inat=inatopts,
     ebird=ebirdopts, vertnet=vertnetopts,
     idigbio=idigbioopts, obis=obisopts, ala=alaopts)
 
@@ -80,7 +80,7 @@ occ <- function(query = NULL, from = "gbif", limit = 500, start = NULL,
   } else if (is.null(query) && is.null(geometry) && !is.null(ids)) {
     ids <- occ_unlistids(ids)
     # if ids is not null (taxon identifiers passed in)
-    # ids can only be passed to gbif and bison for now
+    # ids can only be passed to gbif for now
     # so don't pass anything on to inat or ebird
     tmp <- lapply(ids, occ_loopids, y = limit, s = start, p = page,
       z = geometry, hc = has_coords, d = date, w = callopts,
@@ -106,8 +106,6 @@ occ <- function(query = NULL, from = "gbif", limit = 500, start = NULL,
 
   gbif_sp <- occ_getsplist(tmp, "gbif", sources, type, ds$gbif, query, geometry,
     ids)
-  bison_sp <- occ_getsplist(tmp, "bison", sources, type, ds$bison, query, geometry,
-    ids)
   inat_sp <- occ_getsplist(tmp, "inat", sources, type, ds$inat, query, geometry,
     ids)
   ebird_sp <- occ_getsplist(tmp, "ebird", sources, type, ds$ebird, query, geometry,
@@ -120,7 +118,7 @@ occ <- function(query = NULL, from = "gbif", limit = 500, start = NULL,
     ids)
   ala_sp <- occ_getsplist(tmp, "ala", sources, type, ds$ala,
     query, geometry, ids)
-  p <- list(gbif = gbif_sp, bison = bison_sp, inat = inat_sp, ebird = ebird_sp,
+  p <- list(gbif = gbif_sp, inat = inat_sp, ebird = ebird_sp,
             vertnet = vertnet_sp, idigbio = idigbio_sp, obis = obis_sp,
             ala = ala_sp)
   structure(p, class = "occdat", searched = from)
