@@ -5,19 +5,15 @@
 #'
 #' @param query (character) One to many names. Either a scientific name or a 
 #' common name. Only scientific names supported right now.
-#' @param from (character) Data source to get data from, any combination of 
-#' gbif or bison
+#' @param from (character) Data source to get data from, only gbif
 #' @param limit (numeric) Number of records to return. This is passed across 
 #' all sources. To specify different limits for each source, use the options 
-#' for each source (gbifopts, bisonopts). See Details for more.
-#' @param rank (character) Taxonomic rank to limit search space. Used in GBIF, 
-#' but not used in BISON.
+#' for each source (gbifopts). See Details for more.
+#' @param rank (character) Taxonomic rank to limit search space. Used in GBIF.
 #' @param callopts Options passed on to [crul::HttpClient()], e.g., for 
 #' debugging curl calls, setting timeouts, etc.
 #' @param gbifopts (list) List of named options to pass on to 
 #' [rgbif::name_lookup()]. See also [spocc::occ_names_options()]
-#' @param bisonopts (list) List of named options to pass on to 
-#' [rbison::bison_tax()]. See also [spocc::occ_names_options()]
 #'
 #' @details Not all 7 data sources available from the [occ()] function are
 #' available here, as not all of those sources have functionality to search 
@@ -33,30 +29,24 @@
 #' ## gbif
 #' (res <- occ_names(query = 'Accipiter striatus', from = 'gbif'))
 #' head(res$gbif$data[[1]])
-#'
-#' ## bison
-#' (res <- occ_names(query = '*bear', from = 'bison'))
-#' res$bison$data
 #' }
 
 occ_names <- function(query = NULL, from = "gbif", limit = 100, 
-  rank = "species", callopts=list(), gbifopts = list(), bisonopts = list()) {
+  rank = "species", callopts=list(), gbifopts = list()) {
 
-  sources <- match.arg(from, choices = c("gbif", "bison"), 
+  sources <- match.arg(from, choices = c("gbif"), 
                        several.ok = TRUE)
   tmp <- lapply(query, loopfun, y = limit, w = callopts, src = sources, 
-                op = list(gbi = gbifopts, bis = bisonopts)
+                op = list(gbi = gbifopts)
   )
   gbif_sp <- getnameslist(tmp, "gbif", sources, query, gbifopts)
-  bison_sp <- getnameslist(tmp, "bison", sources, query, bisonopts)
-  structure(list(gbif = gbif_sp, bison = bison_sp), class = "occnames")
+  structure(list(gbif = gbif_sp), class = "occnames")
 }
 
 loopfun <- function(x, y, w, op, src) {
   # x = query; y = limit; w = callopts; op=source options
   gbif_res <- names_gbif(src, x, y, w, op$gbi)
-  bison_res <- names_bison(src, x, y, w, op$bis)
-  list(gbif = gbif_res, bison = bison_res)
+  list(gbif = gbif_res)
 }
 
 getnameslist <- function(tmp, srce, sources, q, opts) {
@@ -83,8 +73,6 @@ print.occnames <- function(x, ...) {
   cat("Summary of results - occurrences found for:", "\n")
   cat(" gbif  :", perspp$gbif[1], "records across", perspp$gbif[2], "species",
       "\n")
-  cat(" bison : ", perspp$bison[1], "records across", perspp$bison[2], "species",
-      "\n")
 }
 
 #' @noRd
@@ -110,27 +98,3 @@ names_gbif <- function(sources, query, limit, callopts, opts){
     emptylist(opts)
   }
 }
-
-#' @noRd
-names_bison <- function(sources, query, limit, callopts, opts){
-  if (any(grepl("bison", sources))) {
-    if (is.null(query)) {
-      emptylist(opts)
-    } else {
-      time <- now()
-      opts$query <- query
-      if (!'limit' %in% names(opts)) opts$rows <- limit
-      opts$callopts <- callopts
-      out <- do.call(bison_tax, opts)
-      if (is.character(out) || is.character(out$data)) {
-        emptylist(opts)
-      } else {
-        dat <- out$names
-        dat$prov <- rep("bison", nrow(dat))
-        list(time = time, found = out$numFound, data = dat, opts = opts)
-      }
-    }
-  } else {
-    emptylist(opts)
-  }
-}
